diff --git mscore/mscore/scoreview.cpp mscore/mscore/scoreview.cpp
index a17931d..194a13b 100644
--- mscore/mscore/scoreview.cpp
+++ mscore/mscore/scoreview.cpp
@@ -80,6 +80,8 @@
 #include "libmscore/keysig.h"
 #include "libmscore/timesig.h"
 
+#include <QtGui>
+
 static const QEvent::Type CloneDrag = QEvent::Type(QEvent::User + 1);
 extern TextPalette* textPalette;
 
@@ -814,6 +816,10 @@ ScoreView::ScoreView(QWidget* parent)
       sm->setInitialState(stateActive);
 
       sm->start();
+            
+            
+      grabGesture(Qt::PinchGesture);
+            
       //-----------------------------------------------------------------------
 
       if (debugMode)
@@ -2332,10 +2338,6 @@ void ScoreView::dragLeaveEvent(QDragLeaveEvent*)
 
 void ScoreView::zoom(int step, const QPoint& pos)
       {
-      QPointF p1 = imatrix.map(QPointF(pos));
-      //
-      //    magnify
-      //
       qreal _mag = mag();
 
       if (step > 0) {
@@ -2348,16 +2350,29 @@ void ScoreView::zoom(int step, const QPoint& pos)
                   _mag /= 1.1;
                   }
             }
+            
+      zoom(_mag, QPointF(pos));
+      }
+
+//---------------------------------------------------------
+//   zoom
+//---------------------------------------------------------
+
+void ScoreView::zoom(qreal _mag, const QPointF& pos)
+      {
+            
+      QPointF p1 = imatrix.map(pos);
+            
       if (_mag > 16.0)
             _mag = 16.0;
       else if (_mag < 0.05)
             _mag = 0.05;
-
+      
       mscore->setMag(_mag);
       setMag(_mag);
       _magIdx = MAG_FREE;
-
-      QPointF p2 = imatrix.map(QPointF(pos));
+            
+      QPointF p2 = imatrix.map(pos);
       QPointF p3 = p2 - p1;
 
       double m = _mag;
@@ -2375,6 +2390,29 @@ void ScoreView::zoom(int step, const QPoint& pos)
       }
 
 //---------------------------------------------------------
+//   gestureEvent
+//---------------------------------------------------------
+
+bool ScoreView::gestureEvent(QGestureEvent *event)
+{
+      if (QGesture *gesture = event->gesture(Qt::PinchGesture)) {
+            // Zoom in/out when receiving a pinch gesture
+            QPinchGesture *pinch = static_cast<QPinchGesture *>(gesture);
+            
+            static qreal magStart = 1.0;
+            
+            if (pinch->state() == Qt::GestureStarted) {
+                  magStart = mag();
+            }
+            if (pinch->changeFlags() & QPinchGesture::ScaleFactorChanged) {
+                  qreal value = pinch->property("scaleFactor").toReal();
+                  zoom(magStart*value, pinch->startCenterPoint());
+            }
+      }
+      return true;
+}
+
+//---------------------------------------------------------
 //   wheelEvent
 //---------------------------------------------------------
 
@@ -4124,6 +4162,9 @@ bool ScoreView::event(QEvent* event)
             Element* e = static_cast<CloneEvent*>(event)->element();
             cloneElement(e);
             }
+      else if (event->type() == QEvent::Gesture) {
+            return gestureEvent(static_cast<QGestureEvent*>(event));
+            }
       return QWidget::event(event);
       }
 
diff --git mscore/mscore/scoreview.h mscore/mscore/scoreview.h
index 84430a7..b57aa90 100644
--- mscore/mscore/scoreview.h
+++ mscore/mscore/scoreview.h
@@ -169,6 +169,7 @@ class ScoreView : public QWidget, public MuseScoreView {
       void saveChord(Xml&);
 
       virtual bool event(QEvent* event);
+      virtual bool gestureEvent(QGestureEvent*);
       virtual void resizeEvent(QResizeEvent*);
       virtual void wheelEvent(QWheelEvent*);
       virtual void dragEnterEvent(QDragEnterEvent*);
@@ -299,6 +300,7 @@ class ScoreView : public QWidget, public MuseScoreView {
       void startUndoRedo();
       void endUndoRedo();
       void zoom(int step, const QPoint& pos);
+      void zoom(qreal _mag, const QPointF& pos);
       void contextPopup(QMouseEvent* ev);
       void setOrigEditObject(Element* e) { origEditObject = e; }
       void editKey(QKeyEvent*);
